/**
 * @packageDocumentation
 * @module Boolean
 */
import { Observable, Subscribable } from 'rxjs';
/**
 * Returns an Observable that emits boolean values from passed source of values
 *
 * @category Create
 *
 * @typeParam T Type of the value from the source Observable
 *
 * @param input Input values to create the Observable source from
 *
 * @example
 * Create an Observable that emits a single boolean value from a string, flip the value
 * ```ts
 * fromBoolean('Hello RxJS Ninja').pipe(flip()).subscribe();
 * ```
 * Output: `false`
 *
 * @example
 * Create an Observable that emits a single boolean from an array of values
 * ```ts
 * fromBoolean(['', 'Hello', 'RxJS', '']).subscribe();
 * ```
 * Output: `false, true, true, false`;
 *
 * @returns Observable that emits a boolean value of the source value Boolean conversion

 */
export declare function fromBoolean<T extends unknown>(input: Subscribable<Iterable<T> | T> | Iterable<T> | T): Observable<boolean>;
